# This example shows how to save the S-parameters resulting from a circuit simulation to a file.
# The results can then later be loaded from file for fast inspection or data processing (see also `s_parameter_save.py`)

import si_fab.all as pdk  # noqa
from ipkiss.technology import get_technology
import ipkiss3.all as i3  # noqa: F401
from picazzo3.filters.ring import RingRectSymm180DropFilter
import numpy as np
import os

TECH = get_technology()  # noqa: F401
# To get a FSR of 10 nm at 1.55 um, we use the following formula
n_g = 2.86
L_fsr_10nm = 1.55**2 / (n_g * 0.01)

# Define coupler parameters
cp = dict(
    cross_coupling1=1j * 0.0784**0.5,
    straight_coupling1=0.9216**0.5,
    reflection_in1=1j * 0.030,  # The backreflection in the coupler
)

# Define the ring resonator
ring = RingRectSymm180DropFilter(name="example_save_ring")
ring_cm = ring.CircuitModel(
    ring_length=L_fsr_10nm,
    coupler_parameters=[cp, cp],  # specify ring length on the model
)  # 2 couplers

# Simulate
wavelengths = np.linspace(1.54, 1.56, 2000)
ring_S = ring_cm.get_smatrix(wavelengths=wavelengths)

# Save result to a TouchStone S-parameter file in the current directory.

curdir = os.path.abspath(os.path.dirname(__file__))
ring_S.to_touchstone(os.path.join(curdir, "example_ring_smatrix"))

print("S-Matrix saved")
